summaryrefslogtreecommitdiff
path: root/examples/v3arch/asyncore/oneliner/manager/cmdgen/getnext-v3-pull-whole-mib-with-options.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/v3arch/asyncore/oneliner/manager/cmdgen/getnext-v3-pull-whole-mib-with-options.py')
-rw-r--r--examples/v3arch/asyncore/oneliner/manager/cmdgen/getnext-v3-pull-whole-mib-with-options.py60
1 files changed, 32 insertions, 28 deletions
diff --git a/examples/v3arch/asyncore/oneliner/manager/cmdgen/getnext-v3-pull-whole-mib-with-options.py b/examples/v3arch/asyncore/oneliner/manager/cmdgen/getnext-v3-pull-whole-mib-with-options.py
index 99eba51..19d7950 100644
--- a/examples/v3arch/asyncore/oneliner/manager/cmdgen/getnext-v3-pull-whole-mib-with-options.py
+++ b/examples/v3arch/asyncore/oneliner/manager/cmdgen/getnext-v3-pull-whole-mib-with-options.py
@@ -1,17 +1,23 @@
-#
-# Command Generator
-#
-# Send SNMP GETNEXT requests using the following options:
-#
-# * with SNMPv3, user 'usr-sha-aes128', SHA auth, AES128 privacy
-# * over Local Domain Sockets
-# * to an Agent at demo.snmplabs.com:161
-# * for all OIDs past IF-MIB (load up all MIBs in search path)
-# * run till end-of-mib condition is reported by Agent OR maxRows == 100
-# * ignoring non-increasing OIDs whenever reported by Agent
-#
-# make sure IF-MIB.py is search path
-#
+"""
+Fetch fixed amount of MIB variables
++++++++++++++++++++++++++++++++++++
+
+Send a series of SNMP GETNEXT requests using the following options:
+
+* with SNMPv3, user 'usr-sha-aes128', SHA auth, AES128 privacy
+* over UDP/IPv4
+* to an Agent at demo.snmplabs.com:161
+* for all OIDs past SNMPv2-MIB
+* run till end-of-mib condition is reported by Agent OR maxRows == 100
+* ignoring non-increasing OIDs whenever reported by Agent
+
+Functionally similar to:
+
+| $ snmpwalk -v3 -lauthPriv -u usr-sha-aes128 -A authkey1 -X privkey1 \
+| -a MD5 -x AES demo.snmplabs.com \
+| SNMPv2-MIB::system
+
+"""#
from pysnmp.entity.rfc3413.oneliner.cmdgen import *
for errorIndication, \
@@ -22,21 +28,19 @@ for errorIndication, \
privProtocol=usmAesCfb128Protocol),
UdpTransportTarget(('demo.snmplabs.com', 161)),
ContextData(),
- ObjectType(ObjectIdentity('IF-MIB', '').loadMibs()),
- lexicographicMode=True, maxRows=100,
- ignoreNonIncreasingOid=True):
- # Check for errors and print out results
+ ObjectType(ObjectIdentity('SNMPv2-MIB')),
+ maxRows=100, ignoreNonIncreasingOid=True):
+
if errorIndication:
print(errorIndication)
break
- else:
- if errorStatus:
- print('%s at %s' % (
- errorStatus.prettyPrint(),
- errorIndex and varBinds[int(errorIndex)-1][0] or '?'
- )
+ elif errorStatus:
+ print('%s at %s' % (
+ errorStatus.prettyPrint(),
+ errorIndex and varBinds[int(errorIndex)-1][0] or '?'
)
- break
- else:
- for varBind in varBinds:
- print(' = '.join([ x.prettyPrint() for x in varBind ]))
+ )
+ break
+ else:
+ for varBind in varBinds:
+ print(' = '.join([ x.prettyPrint() for x in varBind ]))